@@ -57,7 +57,7 @@ AnsiGenerator::AnsiGenerator() {
 
 AnsiGenerator::~AnsiGenerator() {}
 
-string AnsiGenerator::getHeader(const string & title) {
+string AnsiGenerator::getHeader() {
     return string();
 }
 
