@@ -33,6 +33,7 @@ CmdLineOptions::CmdLineOptions(int argc, char *argv[]):
     opt_help (false),
     opt_version (false),
     opt_verbose (false),
+    opt_print_config(false),
     opt_linenumbers (false),
     opt_style (false),
     opt_batch_mode (false),
@@ -42,7 +43,6 @@ CmdLineOptions::CmdLineOptions(int argc, char *argv[]):
     opt_show_langdefs (false),
     opt_printindex(false),
     opt_quiet(false),
-    opt_xslfo_fop(false),
     opt_replacequotes(false),
     opt_babel(false),
     opt_print_progress(false),
@@ -50,7 +50,9 @@ CmdLineOptions::CmdLineOptions(int argc, char *argv[]):
     opt_stylepath_explicit(false),
     opt_force_output(false),
     opt_ordered_list(false),
+    opt_fnames_as_anchors(false),
     configFileRead(false),
+    anchorPrefix("l"),
     helpLang("en"),
     encodingName("ISO-8859-1")
 {
@@ -66,7 +68,7 @@ CmdLineOptions::CmdLineOptions(int argc, char *argv[]):
         {OPT_VERBOSE, 0, 0, S_OPT_VERBOSE},
         {OPT_INC_STYLE, 0, 0, S_OPT_INC_STYLE},
         {OPT_HELP, 0, 0, S_OPT_HELP},
-        {OPT_HELPINT, 1, 0, S_OPT_HELPINT},
+        {OPT_HELP_LANG, 1, 0, S_OPT_HELP_LANG},
         {OPT_LINENO,0,0,S_OPT_LINENO},
         {OPT_STYLE, 1,0,S_OPT_STYLE},
         {OPT_STYLE_OUT, 1, 0,S_OPT_STYLE_OUT},
@@ -86,7 +88,8 @@ CmdLineOptions::CmdLineOptions(int argc, char *argv[]):
         {OPT_LISTLANGS, 0,0,S_OPT_LISTLANGS },
         {OPT_OUTDIR,1,0,S_OPT_OUTDIR},
         {OPT_VERSION,0,0,0},
-        {OPT_FORMATSTYLE,1,0,S_OPT_FORMATSTYLE},
+        {OPT_FORMAT,1,0,S_OPT_FORMAT},
+        {OPT_DEPR_FORMAT,1,0,0},  // deprecated
         {OPT_DATADIR,1,0,S_OPT_DATADIR},
         {OPT_ADDDATADIR,1,0,S_OPT_ADDDATADIR},
         {OPT_INDEXFILE,0,0,S_OPT_INDEXFILE},
@@ -105,16 +108,13 @@ CmdLineOptions::CmdLineOptions(int argc, char *argv[]):
         {OPT_LNR_WIDTH,1,0,S_OPT_LNR_WIDTH},
         {OPT_LNR_START,1,0,S_OPT_LNR_START},
         {OPT_BABEL,0,0,S_OPT_BABEL},
+        {OPT_PAGE_SIZE,1,0,S_OPT_PAGE_SIZE},
+        {OPT_DOC_TITLE,1,0,S_OPT_DOC_TITLE},
+        {OPT_PRINT_CONFIG,0,0,0},
+        {OPT_ANCHOR_PFX,1,0,S_OPT_ANCHOR_PFX},
+        {OPT_ANCHOR_FN,0,0,S_OPT_ANCHOR_FN},
 
-        //remove as soon as APAche fixes the bug in FOP (0.20.5)
-        {OPT_FOP,0,0,S_OPT_FOP},
-
-        //deprecated
-        {OPT_CSSOUT,1,0,0},
-        {OPT_CSSIN,1,0,0},
-        {OPT_INC_CSS,0,0,0},
         {OPT_FORCE_OUTPUT,0,0,0},
-
         {0, 0, 0, 0}
       };
 
@@ -130,21 +130,15 @@ CmdLineOptions::CmdLineOptions(int argc, char *argv[]):
           if (long_options[option_index].name==OPT_VERSION) {
               opt_version = true;
             }
-            if (long_options[option_index].name==OPT_CSSOUT) {
-                styleOutFilename=string(optarg);
-                printDeprecatedWarning(OPT_CSSOUT, OPT_STYLE_OUT);
-            }
-            else if (long_options[option_index].name==OPT_CSSIN) {
-                styleInFilename=string(optarg);
-                printDeprecatedWarning(OPT_CSSIN, OPT_STYLE_IN);
-            }
-            else if (long_options[option_index].name==OPT_INC_CSS) {
-                opt_include_style = true;
-                printDeprecatedWarning(OPT_INC_CSS, OPT_INC_STYLE);
-            }
             else if (long_options[option_index].name==OPT_FORCE_OUTPUT) {
                 opt_force_output = true;
             }
+            else if (long_options[option_index].name==OPT_PRINT_CONFIG) {
+               opt_print_config = true;
+            }
+            else if (long_options[option_index].name==OPT_DEPR_FORMAT) {
+              indentScheme =string(optarg);
+            }
           break;
         case S_OPT_OUT:
           outFilename=string(optarg);
@@ -159,6 +153,9 @@ CmdLineOptions::CmdLineOptions(int argc, char *argv[]):
         case S_OPT_STYLE_IN:
           styleInFilename=string(optarg);
           break;
+        case S_OPT_PAGE_SIZE:
+          pageSize=string(optarg);
+          break;
         case S_OPT_VERBOSE:
           opt_verbose = true;
           break;
@@ -168,7 +165,7 @@ CmdLineOptions::CmdLineOptions(int argc, char *argv[]):
          case S_OPT_INC_STYLE:
           opt_include_style = true;
           break;
-        case S_OPT_HELPINT:
+        case S_OPT_HELP_LANG:
           helpLang=string(optarg);
         case S_OPT_HELP:
           opt_help = true;
@@ -188,7 +185,7 @@ CmdLineOptions::CmdLineOptions(int argc, char *argv[]):
           opt_language = true;
           break;
         case S_OPT_DELTABS:
-          numberSpaces = StringTools::str2int (string(optarg), true);
+          StringTools::str2num<int> (numberSpaces, string(optarg), std::dec);
           break;
         case S_OPT_XHTML:
           outputType=highlight::XHTML;
@@ -203,14 +200,14 @@ CmdLineOptions::CmdLineOptions(int argc, char *argv[]):
           outputType=highlight::LATEX;
           break;
         case S_OPT_XSLFO:
-          outputType=highlight::XSLFO;
+          std::cerr << "\nWARNING: XSL-FO support has been discontinued since"
+                    << " release 2.4.4. XML is generated instead.\n\n";
+        case S_OPT_XML:
+          outputType=highlight::XML;
           break;
         case S_OPT_ANSI:
           outputType=highlight::ANSI;
           break;
-        case S_OPT_XML:
-          outputType=highlight::XML;
-          break;
         case S_OPT_BATCHREC:
           opt_batch_mode = true;
           readDirectory(string(optarg));
@@ -221,6 +218,9 @@ CmdLineOptions::CmdLineOptions(int argc, char *argv[]):
         case S_OPT_ANCHORS:
           opt_attach_line_anchors = true;
           break;
+        case S_OPT_ANCHOR_PFX:
+          anchorPrefix =string(optarg);
+          break;
         case S_OPT_LISTTHEMES:
           opt_show_themes = true;
           break;
@@ -230,7 +230,7 @@ CmdLineOptions::CmdLineOptions(int argc, char *argv[]):
         case S_OPT_OUTDIR:
           outDirectory = validateDirPath(string(optarg));
           break;
-        case S_OPT_FORMATSTYLE:
+        case S_OPT_FORMAT:
           indentScheme =string(optarg);
           break;
         case S_OPT_ENCODING:
@@ -251,9 +251,6 @@ CmdLineOptions::CmdLineOptions(int argc, char *argv[]):
          case S_OPT_WRAP:
           wrappingStyle = highlight::WRAP_DEFAULT;
           break;
-         case S_OPT_FOP:
-          opt_xslfo_fop=true;
-          break;
          case S_OPT_REPLACE_QUOTES:
           opt_replacequotes=true;
           break;
@@ -266,24 +263,27 @@ CmdLineOptions::CmdLineOptions(int argc, char *argv[]):
          case S_OPT_FILLZEROES:
           opt_fill_zeroes=true;
           break;
-          // -- Kafka begins
          case S_OPT_BASE_FONT:
           baseFont=string(optarg);
           break;
          case S_OPT_BASE_FONT_SIZE:
           baseFontSize=string(optarg);
           break;
-         // -- Kafka ends
          case S_OPT_LNR_WIDTH:
-          lineNrWidth=StringTools::str2int(string(optarg), true);
+          StringTools::str2num<int>(lineNrWidth, string(optarg), std::dec);
           break;
          case S_OPT_LNR_START:
-          lineNrStart=StringTools::str2int(string(optarg), true);
+          StringTools::str2num<int>(lineNrStart, string(optarg), std::dec);
           break;
          case S_OPT_ORDERED_LIST:
-            opt_ordered_list = opt_linenumbers = true;
+          opt_ordered_list = opt_linenumbers = true;
           break;
-
+        case S_OPT_DOC_TITLE:
+          docTitle = string(optarg);
+          break;
+        case S_OPT_ANCHOR_FN:
+            opt_fnames_as_anchors=true;
+            break;
         default:
           cerr <<"higlight: Unknown option " <<c<< endl;
         }
@@ -304,8 +304,7 @@ CmdLineOptions::CmdLineOptions(int argc, char *argv[]):
   }
 }
 
-CmdLineOptions::~CmdLineOptions(){
-}
+CmdLineOptions::~CmdLineOptions(){}
 
 const string &CmdLineOptions::getSingleOutFilename()
   {
@@ -359,6 +358,10 @@ bool CmdLineOptions::printDebugInfo()const
   {
     return opt_verbose;
   }
+bool CmdLineOptions::printConfigInfo()const
+  {
+    return opt_print_config;
+  }
 bool CmdLineOptions::quietMode()const
   {
     return opt_quiet;
@@ -367,6 +370,10 @@ bool CmdLineOptions::includeStyleDef()const
   {
       return opt_include_style;
   }
+bool CmdLineOptions::useFNamesAsAnchors() const
+{
+        return opt_fnames_as_anchors;
+}
 
 bool CmdLineOptions::formatSupportsExtStyle(){
       return outputType==highlight::HTML ||
@@ -380,7 +387,7 @@ bool CmdLineOptions::printLineNumbers()const
     return opt_linenumbers;
   }
 
-string CmdLineOptions::getStyleName()const
+string CmdLineOptions::getThemeName()const
   {
     return ( ( opt_style) ? styleName+".style" : "kwrite.style" );
   }
@@ -396,8 +403,9 @@ string CmdLineOptions::getOutFileSuffix()const{
       case highlight::RTF:   return ".rtf";
       case highlight::TEX:
       case highlight::LATEX: return ".tex";
-      case highlight::XSLFO: return ".fo";
+      case highlight::XSLFO: return ".xml";
       case highlight::XML:   return ".xml";
+      case highlight::ANSI:   return ".ansi";
       default:    return ".html";
     }
 }
@@ -417,9 +425,6 @@ bool CmdLineOptions::showLangdefs()const{
 bool CmdLineOptions::outDirGiven()const{
     return !outFilename.empty();
 }
-bool CmdLineOptions::fopCompatible() const {
-   return opt_xslfo_fop;
-}
 bool CmdLineOptions::replaceQuotes() const {
    return opt_replacequotes;
 }
@@ -458,6 +463,14 @@ const string &CmdLineOptions::getLanguage() const {
 const string&CmdLineOptions::getEncoding() const{
     return encodingName;
 }
+
+const string& CmdLineOptions::getAnchorPrefix() const {
+    return anchorPrefix;
+}
+
+const string &CmdLineOptions::getPageSize() const{
+   return pageSize;
+}
 bool CmdLineOptions::printIndexFile() const{
  return opt_printindex && (outputType==highlight::HTML ||
                            outputType==highlight::XHTML);
@@ -480,6 +493,13 @@ bool CmdLineOptions::forceOutput() const {
 const string  CmdLineOptions::getHelpLang() const {
   return helpLang+".help";
 }
+const string &CmdLineOptions::getConfigFilePath() const {
+  return configFilePath;
+}
+
+const string& CmdLineOptions::getDocumentTitle() const {
+   return docTitle;
+}
 
 highlight::WrapMode CmdLineOptions::getWrappingStyle() const {
   return wrappingStyle;
@@ -509,81 +529,84 @@ void CmdLineOptions::loadConfigurationFile()
   #else
     configFilePath = Platform::getAppPath() + "highlight.conf";
   #endif
-  ConfigurationReader presets(configFilePath);
+  ConfigurationReader userConfig(configFilePath);
 
-  if (presets.found())
+  if (userConfig.found())
     {
       string paramVal;
       configFileRead=true;
 
-      styleOutFilename = presets.getParameter(OPT_STYLE_OUT);
-      styleInFilename = presets.getParameter(OPT_STYLE_IN);
-      styleName = presets.getParameter(OPT_STYLE);
+      styleOutFilename = userConfig.getParameter(OPT_STYLE_OUT);
+      styleInFilename = userConfig.getParameter(OPT_STYLE_IN);
+      styleName = userConfig.getParameter(OPT_STYLE);
       opt_style = !styleName.empty();
-      language = presets.getParameter(OPT_SYNTAX);
+      language = userConfig.getParameter(OPT_SYNTAX);
       opt_language = !language.empty();
-      numberSpaces = StringTools::str2int(presets.getParameter(OPT_DELTABS), true);
-      indentScheme = presets.getParameter(OPT_FORMATSTYLE);
-      baseFontSize = presets.getParameter(OPT_BASE_FONT_SIZE);
-      baseFont = presets.getParameter(OPT_BASE_FONT);
+      StringTools::str2num<int>(numberSpaces, userConfig.getParameter(OPT_DELTABS), std::dec);
+      indentScheme = userConfig.getParameter(OPT_FORMAT);
+      baseFontSize = userConfig.getParameter(OPT_BASE_FONT_SIZE);
+      baseFont = userConfig.getParameter(OPT_BASE_FONT);
 
-      paramVal = presets.getParameter(OPT_DATADIR);
+      paramVal = userConfig.getParameter(OPT_DATADIR);
       if (!paramVal.empty()) {
          dataDir=validateDirPath( paramVal);
       }
-      paramVal = presets.getParameter(OPT_ADDDATADIR);
+      paramVal = userConfig.getParameter(OPT_ADDDATADIR);
       if (!paramVal.empty()) {
         additionalDataDir=validateDirPath(paramVal);
       }
-      paramVal = presets.getParameter(OPT_OUTDIR);
+      paramVal = userConfig.getParameter(OPT_OUTDIR);
       if (!paramVal.empty()) {
         outDirectory=validateDirPath(paramVal);
       }
-      paramVal = presets.getParameter(OPT_ENCODING);
+      paramVal = userConfig.getParameter(OPT_ENCODING);
       if (!paramVal.empty()) {
           encodingName=paramVal;
       }
-      paramVal = presets.getParameter(OPT_LNR_WIDTH);
+      paramVal = userConfig.getParameter(OPT_LNR_WIDTH);
       if (!paramVal.empty()) {
-          lineNrWidth=StringTools::str2int(string(paramVal), true);
+          StringTools::str2num<int>(lineNrWidth, string(paramVal), std::dec);
       }
-      paramVal = presets.getParameter(OPT_LNR_START);
+      paramVal = userConfig.getParameter(OPT_LNR_START);
       if (!paramVal.empty()) {
-          lineNrStart=StringTools::str2int(string(paramVal), true);
+          StringTools::str2num<int>(lineNrStart, string(paramVal), std::dec);
       }
+      paramVal = userConfig.getParameter(OPT_ANCHOR_PFX);
+      if (!paramVal.empty()) {
+          anchorPrefix=paramVal;
+      }
+      opt_include_style=getFlag(userConfig.getParameter(OPT_INC_STYLE));
+      opt_verbose=getFlag(userConfig.getParameter(OPT_VERBOSE));
+      opt_ordered_list=getFlag(userConfig.getParameter(OPT_ORDERED_LIST));
+      opt_linenumbers=opt_ordered_list || getFlag(userConfig.getParameter(OPT_LINENO));
+      opt_fragment=getFlag(userConfig.getParameter(OPT_FRAGMENT));
+      opt_attach_line_anchors=getFlag(userConfig.getParameter(OPT_ANCHORS));
+      opt_printindex=getFlag(userConfig.getParameter(OPT_INDEXFILE));
+      opt_quiet=getFlag(userConfig.getParameter(OPT_QUIET));
+      opt_replacequotes=getFlag(userConfig.getParameter(OPT_REPLACE_QUOTES));
+      opt_print_progress=getFlag(userConfig.getParameter(OPT_PROGRESSBAR));
+      opt_fill_zeroes=getFlag(userConfig.getParameter(OPT_FILLZEROES));
+      opt_fnames_as_anchors=getFlag(userConfig.getParameter(OPT_ANCHOR_FN));
 
-      opt_include_style=getFlag(presets.getParameter(OPT_INC_STYLE));
-      opt_verbose=getFlag(presets.getParameter(OPT_VERBOSE));
-      opt_ordered_list=getFlag(presets.getParameter(OPT_ORDERED_LIST));
-      opt_linenumbers=opt_ordered_list || getFlag(presets.getParameter(OPT_LINENO));
-      opt_fragment=getFlag(presets.getParameter(OPT_FRAGMENT));
-      opt_attach_line_anchors=getFlag(presets.getParameter(OPT_ANCHORS));
-      opt_printindex=getFlag(presets.getParameter(OPT_INDEXFILE));
-      opt_quiet=getFlag(presets.getParameter(OPT_QUIET));
-      opt_xslfo_fop=getFlag(presets.getParameter(OPT_FOP));
-      opt_replacequotes=getFlag(presets.getParameter(OPT_REPLACE_QUOTES));
-      opt_print_progress=getFlag(presets.getParameter(OPT_PROGRESSBAR));
-      opt_fill_zeroes=getFlag(presets.getParameter(OPT_FILLZEROES));
-
-      if (getFlag(presets.getParameter(OPT_WRAP))) {
+      if (getFlag(userConfig.getParameter(OPT_WRAP))) {
           wrappingStyle=highlight::WRAP_DEFAULT;
       }
-      if (getFlag(presets.getParameter(OPT_WRAPSIMPLE))) {
+      if (getFlag(userConfig.getParameter(OPT_WRAPSIMPLE))) {
           wrappingStyle=highlight::WRAP_SIMPLE;
       }
-      if (getFlag(presets.getParameter(OPT_XHTML))) {
+      if (getFlag(userConfig.getParameter(OPT_XHTML))) {
           outputType=highlight::XHTML;
-      } else if (getFlag(presets.getParameter(OPT_RTF))) {
+      } else if (getFlag(userConfig.getParameter(OPT_RTF))) {
           outputType=highlight::RTF;
-      } else if (getFlag(presets.getParameter(OPT_TEX))) {
+      } else if (getFlag(userConfig.getParameter(OPT_TEX))) {
           outputType=highlight::TEX;
-      } else if (getFlag(presets.getParameter(OPT_LATEX))) {
+      } else if (getFlag(userConfig.getParameter(OPT_LATEX))) {
           outputType=highlight::LATEX;
-      } else if (getFlag(presets.getParameter(OPT_XSLFO))) {
-          outputType=highlight::XSLFO;
-      } else if (getFlag(presets.getParameter(OPT_ANSI))) {
+      } else if (getFlag(userConfig.getParameter(OPT_XSLFO))) {
+          outputType=highlight::XML;
+      } else if (getFlag(userConfig.getParameter(OPT_ANSI))) {
           outputType=highlight::ANSI;
-      } else if (getFlag(presets.getParameter(OPT_XML))) {
+      } else if (getFlag(userConfig.getParameter(OPT_XML))) {
             outputType=highlight::XML;
       }
     }
@@ -598,11 +621,6 @@ highlight::OutputType CmdLineOptions::getOutputType() const {
     return outputType;
 }
 
-void CmdLineOptions::printDeprecatedWarning(const char *oldOption, const char *newOption){
-    cerr << "Warning: Long option \""<<oldOption << "\" is DEPRECATED.";
-    cerr << " Use \""<<newOption << "\" instead.\n";
-}
-
 // -- Kafka begins
 
 bool CmdLineOptions::hasBaseFont() const {
