@@ -58,10 +58,13 @@
 #define OPT_XSLFO        "xsl-fo"
 #define OPT_FRAGMENT     "fragment"
 #define OPT_ANCHORS      "anchors"
+#define OPT_ANCHOR_PFX   "anchor-prefix"
+#define OPT_ANCHOR_FN    "anchor-filename"
 #define OPT_LISTTHEMES   "list-themes"
 #define OPT_LISTLANGS    "list-langs"
 #define OPT_VERSION      "version"
 #define OPT_IN           "input"
+#define OPT_IN_NAME      "input-name"
 #define OPT_OUT          "output"
 #define OPT_SYNTAX       "syntax"
 #define OPT_STYLE        "style"
@@ -71,11 +74,12 @@
 #define OPT_DELTABS      "replace-tabs"
 #define OPT_BATCHREC     "batch-recursive"
 #define OPT_OUTDIR       "outdir"
-#define OPT_FORMATSTYLE  "format-style"
+#define OPT_FORMAT       "reformat"
+#define OPT_DEPR_FORMAT  "format-style"
 #define OPT_DATADIR      "data-dir"
 #define OPT_ADDDATADIR   "add-data-dir"
 #define OPT_INDEXFILE    "print-index"
-#define OPT_HELPINT      "help-int"
+#define OPT_HELP_LANG      "help-lang"
 #define OPT_WRAP         "wrap"
 #define OPT_WRAPSIMPLE   "wrap-simple"
 #define OPT_QUIET        "quiet"
@@ -93,16 +97,20 @@
 #define OPT_BASE_FONT_SIZE "font-size"
 #define OPT_LNR_START    "line-number-start"
 #define OPT_BABEL        "babel"
+#define OPT_PAGE_SIZE    "page-size"
+#define OPT_PRINT_CONFIG "print-config"
+#define OPT_DOC_TITLE    "doc-title"
 
 
 #define S_OPT_ANSI       'A'
 #define S_OPT_OUT        'o'
 #define S_OPT_IN         'i'
+#define S_OPT_IN_NAME    'g'
 #define S_OPT_SYNTAX     'S'
 #define S_OPT_VERBOSE    'v'
 #define S_OPT_INC_STYLE  'I'
 #define S_OPT_HELP       'h'
-#define S_OPT_HELPINT    'H'
+#define S_OPT_HELP_LANG  'H'
 #define S_OPT_LINENO     'l'
 #define S_OPT_STYLE      's'
 #define S_OPT_STYLE_OUT  'c'
@@ -117,11 +125,13 @@
 #define S_OPT_BATCHREC   'B'
 #define S_OPT_FRAGMENT   'f'
 #define S_OPT_ANCHORS    'a'
+#define S_OPT_ANCHOR_PFX 'y'
+#define S_OPT_ANCHOR_FN  'N'
 #define S_OPT_LISTTHEMES 'w'
 #define S_OPT_LISTLANGS  'p'
 #define S_OPT_OUTDIR     'O'
 
-#define S_OPT_FORMATSTYLE    'F'
+#define S_OPT_FORMAT         'F'
 #define S_OPT_DATADIR        'D'
 #define S_OPT_ADDDATADIR     'E'
 #define S_OPT_INDEXFILE      'C'
@@ -140,13 +150,10 @@
 #define S_OPT_BASE_FONT_SIZE 'K'
 #define S_OPT_ORDERED_LIST   'n'
 #define S_OPT_BABEL          'b'
+#define S_OPT_PAGE_SIZE      'x'
+#define S_OPT_DOC_TITLE      'd'
 
-// deprecated:
-#define OPT_CSSOUT       "css-outfile"
-#define OPT_CSSIN        "css-infile"
-#define OPT_INC_CSS      "include-css"
-
-#define S_OPTIONS_STRING "o:i:S:B:O:s:c:e:t:u:m:F:D:H:E:abfghlnvwpqrzACILYRTZXUV::W::Pk:K:j:"
+#define S_OPTIONS_STRING "abfghlnvwpqrzACILNYRTZXUV::W::Pk:K:j:x:o:i:S:B:O:s:c:e:t:u:m:F:D:H:E:d:y:"
 
 using namespace std;
 
@@ -193,6 +200,9 @@ class CmdLineOptions
     /** \return True if debug information should be printed*/
     bool printDebugInfo()const;
 
+    /** \return True if configuration information should be printed*/
+    bool printConfigInfo()const;
+
     /** \return True if Style definition should be included in output*/
     bool includeStyleDef() const;
 
@@ -200,7 +210,7 @@ class CmdLineOptions
     bool printLineNumbers() const;
 
     /** \return colour theme name */
-    string getStyleName()const ;
+    string getThemeName()const ;
 
     /** gibt true zurck, falls deutsche Hilfe ausgegeben werden soll */
     int helpLanguage() const;
@@ -244,12 +254,18 @@ class CmdLineOptions
     /** \return True if shorthands of LaTeX Babel package should be disabled*/
     bool disableBabelShorthands() const;
 
+    /** \return True if input file name should be used as anchor name */
+    bool useFNamesAsAnchors() const;
+
     /** \return Data directory*/
     const string &getDataDir()const;
 
     /** \return Additional data directory*/
     const string &getAdditionalDataDir()const;
 
+    /** \return  path of user config file*/
+    const string &getConfigFilePath() const;
+
     /** \return True if language syntax is given*/
     bool syntaxGiven() const;
 
@@ -257,7 +273,7 @@ class CmdLineOptions
     bool quietMode() const;
 
     /** \return True if XSL-FO output should be FOP compatible*/
-    bool fopCompatible() const;
+    //bool fopCompatible() const;
 
     /** \return True if progress bar should be printed in batch mode */
     bool printProgress() const;
@@ -280,6 +296,9 @@ class CmdLineOptions
     /** \return Name of indentation scheme file */
     const string &getIndentScheme() const;
 
+    /** \return RTF page size */
+    const string &getPageSize() const;
+
     /** \return Output file format */
     highlight::OutputType getOutputType() const;
 
@@ -300,16 +319,22 @@ class CmdLineOptions
     /** \return True if line numbers should be replaced by ordered list (HTML) */
     bool orderedList() const;
 
-    // -- Kafka begins
     /** \return True if a base font has been given */
     bool hasBaseFont() const ;
+
     /** \return The given base font, empty string by default */
     const string& getBaseFont() const ;
+
+    /** \return Document title */
+    const string& getDocumentTitle() const ;
+
+    /** \return anchor prefix */
+    const string& getAnchorPrefix() const ;
+
     /** \return True if a base font size has been given */
     bool hasBaseFontSize() const ;
     /** \return The given base font size, empty string by default */
     const string& getBaseFontSize() const ;
-    // -- Kafka ends
 
     /** \return line number width */
     int getNumberWidth();
@@ -340,11 +365,12 @@ class CmdLineOptions
     // used to define data directories at runtime
     dataDir, additionalDataDir;
     // name of indenation scheme
-    string indentScheme;
+    string indentScheme,
+           pageSize;
 
-    // -- Kafka begins
     string baseFont, baseFontSize;
-// -- Kafka ends
+    string docTitle;
+
 
 
     bool opt_language;
@@ -352,6 +378,7 @@ class CmdLineOptions
     bool opt_help;
     bool opt_version ;
     bool opt_verbose;
+    bool opt_print_config;
     bool opt_linenumbers;
     bool opt_style;
     bool opt_batch_mode;
@@ -362,7 +389,7 @@ class CmdLineOptions
     bool opt_asformat_output;
     bool opt_printindex;
     bool opt_quiet;
-    bool opt_xslfo_fop;
+    //bool opt_xslfo_fop;
     bool opt_replacequotes;
     bool opt_babel;
     bool opt_print_progress;
@@ -370,9 +397,12 @@ class CmdLineOptions
     bool opt_stylepath_explicit;
     bool opt_force_output;
     bool opt_ordered_list;
+    bool opt_fnames_as_anchors;
 
     bool configFileRead;
 
+    string anchorPrefix;
+
     string helpLang, encodingName;
     string configFilePath;
 
@@ -396,8 +426,6 @@ class CmdLineOptions
 
     /** \return Valid path name */
     string validateDirPath(const string & path);
-
-    void printDeprecatedWarning(const char *oldOption, const char *newOption);
   };
 
 #endif
