@@ -22,7 +22,7 @@
 #include "rtfgenerator.h"
 #include "latexgenerator.h"
 #include "texgenerator.h"
-#include "xslfogenerator.h"
+//#include "xslfogenerator.h"
 #include "xmlgenerator.h"
 #include "re/Matcher.h"
 
@@ -43,6 +43,9 @@ CodeGenerator * CodeGenerator::getInstance(OutputType type) {
      case HTML:
         generator = new HtmlGenerator();
         break;
+      case XHTML:
+        generator = new XHtmlGenerator();
+        break;
       case TEX:
         generator = new TexGenerator ();
         break;
@@ -52,15 +55,10 @@ CodeGenerator * CodeGenerator::getInstance(OutputType type) {
       case RTF:
         generator = new RtfGenerator ();
         break;
-      case XSLFO:
-        generator = new XslFoGenerator();
-        break;
+      case XSLFO:  // TODO remove
       case XML:
         generator = new XmlGenerator();
         break;
-      case XHTML:
-        generator = new XHtmlGenerator();
-        break;
       #ifndef __WXMSW__
       case ANSI:
         generator = new AnsiGenerator ();
@@ -82,6 +80,7 @@ CodeGenerator::CodeGenerator(highlight::OutputType type)
    :in(NULL),
     out(NULL),
     encoding("none"),
+    docTitle("Source file"),
     maskWs(false),
     excludeWs(false),
     fragmentOutput(false),
@@ -92,6 +91,7 @@ CodeGenerator::CodeGenerator(highlight::OutputType type)
     includeStyleDef(false),
     lineIndex(0),
     lineNumberWidth(DEFAULT_LINE_NR_WIDTH),
+    terminatingChar('\0'),
     formatter(NULL),
     preFormatter(NULL),
     formattingEnabled(false),
@@ -104,49 +104,66 @@ CodeGenerator::~CodeGenerator()
 {
   delete preFormatter;
   delete formatter;
+//cerr << "~CodeGenerator()\n";
 }
 
 /** Getter and Setter*/
 
 void CodeGenerator::setSpecialOptions(bool htmlAttachAnchors,bool htmlOrderedList,
                            bool latexReplQuotes, bool latexDisableShorthands,
-                           bool xslFopCompatible) {
+                           const string& rtfPageSize, const string& htmlAnchorPrefix) {
    switch (outputType) {
-     case XHTML:
-          ((XHtmlGenerator*)this)->setAttachAnchors(htmlAttachAnchors);
-          ((XHtmlGenerator*)this)->setOrderedList(htmlOrderedList);
-          break;
      case HTML:
           ((HtmlGenerator*)this)->setAttachAnchors(htmlAttachAnchors);
+          ((HtmlGenerator*)this)->setAnchorPrefix(htmlAnchorPrefix);
           ((HtmlGenerator*)this)->setOrderedList(htmlOrderedList);
           break;
-     case XSLFO:
-          ((XslFoGenerator*)this)->setFopCompatible(xslFopCompatible);
+     case XHTML:
+          ((XHtmlGenerator*)this)->setAttachAnchors(htmlAttachAnchors);
+          ((XHtmlGenerator*)this)->setAnchorPrefix(htmlAnchorPrefix);
+          ((XHtmlGenerator*)this)->setOrderedList(htmlOrderedList);
           break;
      case LATEX:
           ((LatexGenerator*)this)->setReplaceQuotes(latexReplQuotes);
           ((LatexGenerator*)this)->setDisableShorthands(latexDisableShorthands);
+          break;
+     case RTF:
+          ((RtfGenerator*)this)->setPageSize(rtfPageSize);
+          break;
+  /*   case XSLFO:
+          ((XslFoGenerator*)this)->setFopCompatible(xslFopCompatible);
+          break;*/
      default: break;
    }
 }
 
-bool CodeGenerator::initStyle(const string& stylePath) {
-  this->stylePath=stylePath;
-  return docStyle.load(stylePath);
+void CodeGenerator::setHTMLAnchorPrefix(const string & p){
+        if (outputType==HTML)
+            ((HtmlGenerator*)this)->setAnchorPrefix(p);
+        if (outputType==XHTML)
+            ((XHtmlGenerator*)this)->setAnchorPrefix(p);
 }
+
+bool CodeGenerator::initTheme(const string& themePath) {
+  this->themePath=themePath;
+  return docStyle.load(themePath);
+}
+
 const string& CodeGenerator::getStyleName(){
-  return stylePath;
+  return themePath;
 }
 
 void CodeGenerator::setLineNumberWidth(int w) {
   lineNumberWidth=w;
 }
+
 int CodeGenerator::getLineNumberWidth(){
   return lineNumberWidth;
 }
+
 void CodeGenerator::setPrintLineNumbers(bool flag, unsigned int startCnt){
   showLineNumbers=flag;
-  lineNumberOffset = startCnt-1;
+  if (startCnt) lineNumberOffset = startCnt-1;
 }
 
 bool CodeGenerator::getPrintLineNumbers(){
@@ -219,6 +236,14 @@ const string& CodeGenerator::getBaseFontSize()  {
    }
 }
 
+void CodeGenerator::setTitle(const string & title){
+        if (!title.empty()) docTitle= title;
+}
+
+string &CodeGenerator::getTitle(){
+        return docTitle;
+}
+
 void CodeGenerator::setEncoding(const string& encodingName){
    encoding = encodingName;
 }
@@ -250,7 +275,8 @@ LanguageDefinition &CodeGenerator::getLanguage(){
 
 void CodeGenerator::reset()
 {
-  lineIndex = lineNumber = 0;
+  lineIndex = 0;
+  lineNumber = 0;
   line.clear();
 }
 
@@ -260,20 +286,14 @@ Im SymbolString stehen die den einzelnen Symbolen zugeordneten Konstanten
 immer HINTER diesen Symbolen*/
 State CodeGenerator::getState(const string &s, unsigned int searchPos)
 {
-  unsigned int i= searchPos+1, result=0;
+  string::size_type pos = s.find_first_of("1234567890", searchPos+1);
+  if (pos==string::npos) return _UNKNOWN;
 
-  // nach Ziffer in s suchen
-  // TODO replace loops by find methods
-  do {
-      ++i;
-  } while ((i<s.length()) && !isdigit(s[i])) ;
+  string::size_type pos2 = s.find(' ', pos);
+  int result=_UNKNOWN;
+  StringTools::str2num<int>(result, s.substr(pos, pos2-pos), std::dec);
 
-  // Zahl zusammensetzen
-  while ((i<s.length()) && isdigit(s[i])){
-    result = result *10 + (s[i]-'0');
-    ++i;
-  }
-  return ((result)? (State)result:_UNKNOWN);
+  return (State)result;
 }
 
 unsigned int CodeGenerator::getLineNumber()
@@ -283,7 +303,7 @@ unsigned int CodeGenerator::getLineNumber()
 
 bool CodeGenerator::readNewLine(string &newLine){
   bool eof;
-  terminatingChar=newLine[lineIndex-1];
+  if (lineIndex) terminatingChar=newLine[lineIndex-1];
   if (formattingPossible && formattingEnabled) {
      eof=!formatter->hasMoreLines();
      if (!eof) {
@@ -310,10 +330,11 @@ void CodeGenerator::matchRegex(const string &line){
         RegexElement *regexElem = langInfo.getRegexElements()[i];
         Matcher * matcher = regexElem->rePattern->createMatcher(line);
         while (matcher->findNextMatch()) {
-            regexGroups.insert( make_pair(matcher->getStartingIndex(matcher->getGroupNum()-1)+1,
-                                          new ReGroup(regexElem->open,
-                                                      matcher->getGroup(matcher->getGroupNum()-1).size(),
-                                                      regexElem->kwClass)) );
+            regexGroups.insert(
+            make_pair(matcher->getStartingIndex(matcher->getGroupNum()-1)+1,
+                      new ReGroup(regexElem->open,
+                                  matcher->getGroup(matcher->getGroupNum()-1).size(),
+                                  regexElem->kwClass)) );
         }
         delete matcher;
    }
@@ -345,7 +366,7 @@ unsigned char CodeGenerator::getInputChar()
   return line[lineIndex++];
 }
 
-State CodeGenerator::getCurrentState (bool lastStateWasNumber)
+State CodeGenerator::getCurrentState ()
 {
 
   unsigned char c;
@@ -377,19 +398,12 @@ State CodeGenerator::getCurrentState (bool lastStateWasNumber)
        unsigned int oldIndex= lineIndex;
        if (regexGroups[oldIndex]->length>1) lineIndex+= regexGroups[lineIndex]->length-1;
 
-       // TODO join code....
-       if (regexGroups[oldIndex]->state==IDENTIFIER_BEGIN) {
-           string reservedWord=(langInfo.isIgnoreCase()) ?
-                   StringTools::lowerCase(token):token;
+       if (regexGroups[oldIndex]->state==IDENTIFIER_BEGIN || regexGroups[oldIndex]->state==KEYWORD) {
+           string reservedWord=(langInfo.isIgnoreCase()) ? StringTools::lowerCase(token):token;
            currentKeywordClass=langInfo.isKeyword(reservedWord);
+           if (!currentKeywordClass && regexGroups[oldIndex]->state==KEYWORD)
+               currentKeywordClass = regexGroups[oldIndex]->kwClass;
            return (currentKeywordClass) ? KEYWORD : STANDARD;
-       }
-       else if (regexGroups[oldIndex]->state==KEYWORD) {
-           string reservedWord=(langInfo.isIgnoreCase()) ?
-                   StringTools::lowerCase(token):token;
-           int isListedKeyword = langInfo.isKeyword(reservedWord);
-           currentKeywordClass=(isListedKeyword)? isListedKeyword : regexGroups[oldIndex]->kwClass;
-           return KEYWORD;
        } else {
            return regexGroups[oldIndex]->state;
         }
@@ -611,15 +625,19 @@ bool CodeGenerator::initIndentationScheme(const string &schemePath){
        }
 
        if (!indentSpaces.empty()){
-         formatter->setSpaceIndentation(StringTools::str2int(indentSpaces));
+         int intVal=0;
+         StringTools::str2num<int>(intVal, indentSpaces, std::dec);
+         formatter->setSpaceIndentation(intVal);
        }
        if (!minConditionalIndent.empty()){
-         formatter->setMinConditionalIndentLength(
-                      StringTools::str2int(minConditionalIndent));
+         int intVal=0;
+         StringTools::str2num<int>(intVal, minConditionalIndent, std::dec);
+         formatter->setMinConditionalIndentLength(intVal);
        }
        if (!maxInStatementIndent.empty()){
-         formatter->setMinConditionalIndentLength(
-                      StringTools::str2int(maxInStatementIndent));
+         int intVal=0;
+         StringTools::str2num<int>(intVal, maxInStatementIndent, std::dec);
+         formatter->setMinConditionalIndentLength(intVal);
        }
     }
     formattingEnabled=(formatter != NULL);
@@ -659,7 +677,7 @@ LoadResult CodeGenerator::initLanguage(const string& langDefPath){
 }
 
 ParseError CodeGenerator::generateFile (const string &inFileName,
-                                       const string &outFileName)
+                                        const string &outFileName)
 {
   if (!docStyle.found()) {
     return BAD_STYLE;
@@ -686,7 +704,7 @@ ParseError CodeGenerator::generateFile (const string &inFileName,
        formatter->init(new astyle::ASStreamIterator(in));
     }
     if (! fragmentOutput){
-      *out << getHeader(inFileName);
+      *out << getHeader();
     }
 
     printBody();
@@ -705,7 +723,7 @@ ParseError CodeGenerator::generateFile (const string &inFileName,
   return error;
 }
 
-string CodeGenerator::generateString(const string &input, const string &title){
+string CodeGenerator::generateString(const string &input){
 
   if (!docStyle.found()) {
     return "";
@@ -724,7 +742,7 @@ string CodeGenerator::generateString(const string &input, const string &title){
        formatter->init(new astyle::ASStreamIterator(in));
   }
   if (! fragmentOutput){
-    *out << getHeader(title);
+    *out << getHeader();
   }
 
   printBody();
@@ -741,8 +759,8 @@ string CodeGenerator::generateString(const string &input, const string &title){
   return result;
 }
 
-const char* CodeGenerator::generateCString(const string &input, const string &title) {
-  return generateString(input, title).c_str();
+const char* CodeGenerator::generateCString(const string &input) {
+  return generateString(input).c_str();
 }
 
 unsigned int CodeGenerator::getStyleID(State s, unsigned int kwClassID){
@@ -780,10 +798,17 @@ void CodeGenerator::openKWTag(unsigned int kwClassID){
 void CodeGenerator::processRootState()
 {
 
+  bool eof=false,
+       firstLine=true; // avoid newline before printing the first output line
+
   if (langInfo.highlightingDisabled()){
      string line;
      while (getline(*in, line)){
-       *out << maskString(line) << getNewLine();
+       ++lineNumber;
+       insertLineNumber(!firstLine);
+       flushWs();
+       firstLine=false;
+       *out << maskString(line);
      }
      *out << flush;
      return;
@@ -791,12 +816,10 @@ void CodeGenerator::processRootState()
 
   State state=STANDARD;
 
-  bool eof=false,
-       firstLine=true; // avoid newline before printing the first output line
   openTag(STANDARD);
   do {
     // determine next state
-    state= getCurrentState(state==NUMBER);
+    state= getCurrentState();
 
     // handle current state
     switch(state)
@@ -915,7 +938,7 @@ bool CodeGenerator::processNumberState(){
   openTag(NUMBER);
   do {
     printMaskedToken(newState!=_WS);
-    newState= getCurrentState(true);
+    newState= getCurrentState();
     switch(newState)
       {
       case _WS:
@@ -1107,6 +1130,8 @@ bool CodeGenerator::processStringState(State oldState)
           printMaskedToken();
           break;
       case STRING:
+        // if there exist multiple string delimiters, close string if
+        // current delimiters is equal to the opening delimiter
         exitState= openStringDelimiter==token;
         printMaskedToken();
         break;
@@ -1203,7 +1228,7 @@ bool CodeGenerator::processSymbolState(){
   openTag(SYMBOL);
   do {
     printMaskedToken(newState!=_WS);
-    newState= getCurrentState(true);
+    newState= getCurrentState();
     switch(newState)
       {
      case _WS:
@@ -1313,6 +1338,7 @@ void CodeGenerator::insertLineNumber(bool insertNewLine) {
     if (insertNewLine){
     wsBuffer += getNewLine();
   }
+
   if (showLineNumbers) {
     ostringstream os;
     ostringstream numberPrefix;
