@@ -15,28 +15,36 @@
 
 namespace highlight {
 
-/** states which may occour during input file parsing*/
+/** states which may occour during input file parsing
+    TODO Clean up!
+*/
 enum State {
   STANDARD=0,
   STRING,
   NUMBER,
   SL_COMMENT,
-  ML_COMMENT_BEGIN,
+  ML_COMMENT,
   ESC_CHAR,
-  DIRECTIVE_LINE,
+  DIRECTIVE,
   DIRECTIVE_STRING,
   LINENUMBER,
   SYMBOL,
 
-  // Konstanten ab hier duefen nicht mehr als Array-Indizes benutzt werden!!
+  // don't use constants > 10 as array indices!
   KEYWORD,
+  STRING_END,
+  NUMBER_END,
+  SL_COMMENT_END,
   ML_COMMENT_END,
-  DIRECTIVE_LINE_END,
+  ESC_CHAR_END,
+  DIRECTIVE_END,
+  SYMBOL_END,
   TAG_BEGIN,
   TAG_END,
-  KEYWORD_BEGIN,
+  //KEYWORD_BEGIN,
   KEYWORD_END,
-  ESC_CHAR_EXT,  // escape character outside of strings
+  IDENTIFIER_BEGIN,
+  IDENTIFIER_END,
 
   _UNKNOWN=100,
   _EOL,
