@@ -19,7 +19,7 @@
 
 #define IDENTIFIER_RE "[a-zA-Z_]\\w*"
 
-#define DIGIT_RE      "(?:0x|0X)[0-9a-fA-F]+|\\d*[\\.]?\\d+(?:[eE][\\-\\+]\\d+)?[lLuU]?"
+#define NUMBER_RE     "(?:0x|0X)[0-9a-fA-F]+|\\d*[\\.]?\\d+(?:[eE][\\-\\+]\\d+)?[lLuU]?"
 
 
 using namespace std;
@@ -230,7 +230,7 @@ bool LanguageDefinition::load(const string& langDefPath, bool clear)
 
       // use hardcoded regex if not defined in language definition
       string user_def_re = extractRE(langDef.getParameter("digit"));
-      string re_digit = (user_def_re.empty()) ? DIGIT_RE : user_def_re;
+      string re_digit = (user_def_re.empty()) ? NUMBER_RE : user_def_re;
 
       user_def_re = extractRE(langDef.getParameter("identifier"));
       string re_identifier= (user_def_re.empty()) ? IDENTIFIER_RE : user_def_re;
@@ -253,6 +253,8 @@ bool LanguageDefinition::load(const string& langDefPath, bool clear)
       allowExtEscape = getFlag(langDef.getParameter("allowextescape"));
       vhdlMode= getFlag(langDef.getParameter("vhdl_mode"));
 
+      langDesc = langDef.getParameter("description");
+
       string fileToInclude=langDef.getParameter("include");
       if (!fileToInclude.empty()){
         string::size_type Pos = langDefPath.find_last_of(Platform::pathSeparator);
