@@ -46,9 +46,8 @@ class LatexGenerator : public highlight::CodeGenerator
     ~LatexGenerator();
 
    /** prints document header
-       \param  title Title of the document
     */
-    string getHeader(const string & title);
+    string getHeader();
 
     /** Prints document footer*/
     string getFooter();
