@@ -2,7 +2,7 @@
                           main.cpp  -  description
                              -------------------
     begin                : Die Apr 23 22:16:35 CEST 2002
-    copyright            : (C) 2002-2004 by Andre Simon
+    copyright            : (C) 2002-2006 by Andre Simon
     email                : andre.simon1@gmx.de
 
 
@@ -32,23 +32,17 @@ void HighlightApp::printVersionInfo()
 {
   cout << "\n highlight version "
        << HIGHLIGHT_VERSION
-       << "\n Copyright (C) 2002-2005 Andre Simon <andre.simon1 at gmx.de>"
+       << "\n Copyright (C) 2002-2006 Andre Simon <andre.simon1 at gmx.de>"
        << "\n\n Artistic Style Classes (1.15.3)"
        << "\n Copyright (C) 1998-2002 Tal Davidson <davidsont at bigfoot.com>"
        << "\n\n Dirstream Classes (0.4)"
        << "\n Copyright (C) 2002-2004 Benjamin Kaufmann <hume at c-plusplus.de>"
-       << "\n\n Regex library (0.02a)"
-       << "\n Copyright (C) 2003-2005 Jeffery Stuart <stuart at cs.unr.edu>"
+       << "\n\n Regex library (1.05.02)"
+       << "\n Copyright (C) 2003-2006 Jeffery Stuart <stuart at cs.unr.edu>"
        << "\n\n This software is released under the terms of the GNU General "
        << "Public License."
        << "\n For more information about these matters, see the file named "
        << "COPYING.\n\n";
-       #ifdef USE_LOCAL_GETOPT
-         cout   << " (Built with USE_LOCAL_GETOPT flag set.)\n";
-       #endif
-       #ifdef HL_DATA_DIR
-        cout    << " (HL_DATA_DIR: \"" <<HL_DATA_DIR<< "\" )\n";
-       #endif
 }
 
 void HighlightApp::printBadInstallationInfo()
@@ -64,10 +58,8 @@ bool HighlightApp::listInstalledFiles(bool showThemes)
 {
   vector <string> filePaths;
   string wildcard=(showThemes)? "*.style":"*.lang";
-  unsigned int suffixLength=wildcard.length()-1;
-
-  string searchDir = ((showThemes) ? dataDir.getThemeDir():
-                                     dataDir.getLangDefDir()) + wildcard;
+  string directory=(showThemes) ? dataDir.getThemeDir(): dataDir.getLangDefDir();
+  string searchDir = directory + wildcard;
 
   bool directoryOK = Platform::getDirectoryEntries(filePaths, searchDir, true);
   if (!directoryOK) {
@@ -79,20 +71,14 @@ bool HighlightApp::listInstalledFiles(bool showThemes)
 
   cout << "\n  Installed "
        << ((showThemes)? "themes":"language definitions ")
-       << "(located in "
-       << ((showThemes)?dataDir.getThemeDir():dataDir.getLangDefDir())
-       << ") :\n"
-       << endl;
+       << "(located in " << directory << ") :\n\n";
 
   sort(filePaths.begin(), filePaths.end());
-  string  temp;
+  string temp;
 
   for (unsigned int i=0;i< filePaths.size(); i++){
-    if (showThemes)
-      temp = (filePaths[i]).substr(dataDir.getThemeDir().length());
-    else
-      temp = (filePaths[i]).substr(dataDir.getLangDefDir().length());
-    cout << "  "<<temp.substr(0, temp.length()- suffixLength) << endl;
+      temp = (filePaths[i]).substr(directory.length());
+      cout << "  "<<temp.substr(0, temp.length()- wildcard.length()+1) << endl;
   }
   cout <<"\n  Use name of the desired "
        << ((showThemes)?"theme":"language")
@@ -105,24 +91,47 @@ bool HighlightApp::listInstalledFiles(bool showThemes)
 void HighlightApp::printDebugInfo(highlight::LanguageDefinition &lang,
                                    const string & langDefPath)
 {
-   cerr << "\nLoading language definition: " << langDefPath;
-   cerr << "\n\nSYMBOLS:\n" << lang.getSymbolString();
+   cerr << "\nLoading language definition:\n" << langDefPath;
+   cerr << "\n\nDescription: " << lang.getDescription();
+   cerr << "\n\nSYMBOLS (followed by states):\n" << lang.getSymbolString();
    cerr << "\n\nREGEX:\n";
    highlight::RegexElement *re=NULL;
    for (unsigned int i=0; i<lang.getRegexElements().size(); i++){
       re = lang.getRegexElements()[i];
       cerr << "State "<<re->open<<":\t"<<re->rePattern->getPattern()<<"\n";
    }
-   cerr << "\n\nKEYWORDS: ";
+   cerr << "\nKEYWORDS:\n";
    highlight::KeywordMap::iterator it;
    highlight::KeywordMap keys=lang.getKeywords();
-   cerr << "\n\nID    Keyword \n";
-   for (it=keys.begin(); it!=keys.end();it++){
-      cerr << it->second
-           << "  <- \""
-           << it->first <<"\"\n";
+   for (it=keys.begin(),
+        cerr << it->first << "("<< it->second << ")";
+        it!=keys.end();it++) {
+          cerr << ", "<<it->first
+               << "("<< it->second << ")";
    }
-   cerr <<"\n";
+   cerr <<"\n\n";
+}
+
+void HighlightApp::printConfigInfo(const string& configFile)
+{
+ cout << "\nRoot paths (modified by --" OPT_DATADIR  " and --" OPT_ADDDATADIR "):\n";
+ cout << "  Data directory:         "<<dataDir.getDir()<<"\n";
+ if (!dataDir.getAdditionalDataDir().empty())
+     cout << "  User defined directory: "<<dataDir.getAdditionalDataDir()<<"\n";
+ cout << "\nDefault search paths (overidden by option --" OPT_ADDDATADIR "):\n";
+ cout << "  Language definitions:   "<<dataDir.getLangDefDir()<<"\n";
+ cout << "  Colour themes:          "<<dataDir.getThemeDir()<<"\n";
+ cout << "  Indentation schemes:    "<<dataDir.getIndentSchemesDir()<<"\n";
+ cout << "  Configuration files:    "<<dataDir.getConfDir()<<"\n";
+ cout << "\nUser configuration:       "<<configFile<<"\n\n";
+
+ #ifdef USE_LOCAL_GETOPT
+   cout << "Compiler directive USE_LOCAL_GETOPT defined.\n";
+ #endif
+ #ifdef HL_DATA_DIR
+   cout << "Compiler directive HL_DATA_DIR = " <<HL_DATA_DIR<< "\n";
+ #endif
+ cout << endl;
 }
 
 string HighlightApp::getFileSuffix(const string &fileName) {
@@ -131,24 +140,38 @@ string HighlightApp::getFileSuffix(const string &fileName) {
          "" : fileName.substr(ptPos+1, fileName.length());
 }
 
-bool HighlightApp::loadMapConfig(const string& name, StringMap* map){
-    string extPath=dataDir.getConfDir() + name + ".conf";
-    ConfigurationReader config(extPath);
+bool HighlightApp::loadFileTypeConfig(const string& name, StringMap* extMap, StringMap* shebangMap){
+    if (!extMap || !shebangMap) return false;
+    string confPath=dataDir.getConfDir() + name + ".conf";
+    ConfigurationReader config(confPath);
     if (config.found() )
     {
         stringstream values;
         string paramName, paramVal;
         for (unsigned int i=0;i<config.getParameterNames().size();i++){
             paramName = config.getParameterNames()[i];
-            values.str(config.getParameter(paramName)) ;
-            while (values >> paramVal) {
-                map->insert(make_pair( paramVal,  paramName));
+
+            if (paramName.find("ext") != string::npos){
+                values.str(config.getParameter(paramName)) ;
+		paramName = StringTools::getParantheseVal(paramName);
+            	while (values >> paramVal) {
+	   		extMap->insert(make_pair( paramVal,  paramName));
+            	}
+            	values.clear();
             }
-            values.clear();
+	    else if (paramName.find("shebang") != string::npos){
+                values.str(config.getParameter(paramName)) ;
+		paramName = StringTools::getParantheseVal(paramName);
+            	while (values >> paramVal) {
+	   		shebangMap->insert(make_pair( paramVal,  paramName));
+            	}
+            	values.clear();
+            }
+
         }
         return true;
     } else {
-        cerr << "highlight: Configuration file "<< extPath << " not found.\n";
+        cerr << "highlight: Configuration file "<< confPath << " not found.\n";
         return false;
     }
 }
@@ -203,13 +226,12 @@ void HighlightApp::printIOErrorReport(unsigned int numberErrorFiles,
          << numberErrorFiles
          << " failures not shown, use --"
          << OPT_VERBOSE
-         << " switch to print all paths]\n";
+         << " switch to print all failures]\n";
   }
 }
 
 string HighlightApp::analyzeFile(const string& file){
-    if (scriptShebangs.empty()) loadMapConfig("scriptre", &scriptShebangs);
-    ifstream inFile(file.c_str());
+    ifstream inFile(file.c_str());  //TODO auch stdin lesen!
     string firstLine;
     getline (inFile, firstLine);
     StringMap::iterator it;
@@ -221,7 +243,6 @@ string HighlightApp::analyzeFile(const string& file){
 
 string HighlightApp::guessFileType(const string& suffix, const string &inputFile)
 {
-    if (extensions.empty()) loadMapConfig("extensions", &extensions);
     string fileType = (extensions.count(suffix)) ? extensions[suffix] : suffix ;
     if (!fileType.empty()) return fileType;
     return analyzeFile(inputFile);
@@ -230,9 +251,6 @@ string HighlightApp::guessFileType(const string& suffix, const string &inputFile
 
 int HighlightApp::run(int argc, char**argv){
 
-    //cerr << "***THIS IS A BETA RELEASE***\nPlease use the contact form at www.andre-simon.de to report bugs,\n";
-    //cerr <<"especially concerning the new regex features.\n";
-
   //get command line options
   CmdLineOptions options(argc, argv);
 
@@ -255,6 +273,11 @@ int HighlightApp::run(int argc, char**argv){
     return EXIT_SUCCESS;
   }
 
+  if (options.printConfigInfo()) {
+    printConfigInfo(options.getConfigFilePath());
+    return EXIT_SUCCESS;
+  }
+
   if  (options.printHelp())  {
     Help::printHelp(dataDir.getHelpMsgDir() + options.getHelpLang());
     return EXIT_SUCCESS;
@@ -264,15 +287,18 @@ int HighlightApp::run(int argc, char**argv){
     return listInstalledFiles(options.showThemes())?EXIT_SUCCESS:EXIT_FAILURE;
   }
 
+  loadFileTypeConfig("filetypes", &extensions, &scriptShebangs);
   // list of input files
   const  vector <string> inFileList=options.getInputFileNames();
 
-  string stylePath=dataDir.searchForTheme(options.getStyleName());
+  string themePath=dataDir.searchForTheme(options.getThemeName());
 
   highlight::CodeGenerator *generator =
     highlight::CodeGenerator::getInstance(options.getOutputType());
 
-  generator->initStyle(stylePath);
+  assert (generator!=NULL);
+
+  generator->initTheme(themePath);
   generator->setStyleInputPath(options.getStyleInFilename());
   generator->setStyleOutputPath(options.getStyleOutFilename());
   generator->setIncludeStyle(options.includeStyleDef());
@@ -291,15 +317,13 @@ int HighlightApp::run(int argc, char**argv){
 
   generator->setSpecialOptions(options.attachLineAnchors(),options.orderedList(),
                                options.replaceQuotes(), options.disableBabelShorthands(),
-                               options.fopCompatible());
-
-  assert (generator!=NULL);
+                               options.getPageSize(), options.getAnchorPrefix());
 
   bool styleFileWanted = !options.fragmentOutput() || options.styleOutPathDefined();
 
   if (!generator->styleFound() ) {
     cerr << "highlight: Could not find style "
-         << stylePath
+         << themePath
          << ".\n";
     highlight::CodeGenerator::deleteInstance();
     return EXIT_FAILURE;
@@ -322,6 +346,7 @@ int HighlightApp::run(int argc, char**argv){
      cerr << "highlight: Output directory \""
           << outDirectory
 	  << "\" does not exist.\n";
+     highlight::CodeGenerator::deleteInstance();
      return EXIT_FAILURE;
   }
 
@@ -354,7 +379,7 @@ int HighlightApp::run(int argc, char**argv){
                numBadOutput=0;
 
   vector<string> badFormattedFiles, badInputFiles, badOutputFiles;
-  string outFilePath;
+  string inFileName, outFilePath;
   string suffix, lastSuffix;
 
   if (options.syntaxGiven()) {  // user defined language definition, valid for all files
@@ -393,10 +418,13 @@ int HighlightApp::run(int argc, char**argv){
         lastSuffix = suffix;
     }
 
+    string::size_type pos=(inFileList[i]).find_last_of(Platform::pathSeparator);
+    inFileName = inFileList[i].substr(pos+1);
+
     if (options.enableBatchMode()){
-      string::size_type pos=(inFileList[i]).find_last_of(Platform::pathSeparator);
+
       outFilePath = outDirectory;
-      outFilePath += inFileList[i].substr(pos+1);
+      outFilePath += inFileName;
       outFilePath += options.getOutFileSuffix();
 
       if (!options.quietMode()) {
@@ -410,6 +438,13 @@ int HighlightApp::run(int argc, char**argv){
         outFilePath = options.getSingleOutFilename();
      }
 
+     if (options.useFNamesAsAnchors()){
+            generator->setHTMLAnchorPrefix(inFileName);
+     }
+
+     generator->setTitle(options.getDocumentTitle().empty()?
+                    inFileList[i] /*inFileName */ :options.getDocumentTitle());
+
      highlight::ParseError error = generator->generateFile(inFileList[i], outFilePath);
 
      if (error==highlight::BAD_INPUT){
