@@ -23,7 +23,7 @@
 namespace Platform
 {
 	extern const char pathSeparator;
-	extern const std::string pathSeparatorStr;
+	//extern const std::string pathSeparatorStr;
 
 	std::string getAppPath();
 
