@@ -39,6 +39,20 @@ namespace highlight {
 * @author Andre Simon
 */
 
+
+struct PageSize {
+  int width;
+  int height;
+  PageSize(){
+  }
+  PageSize(int w, int h){
+    width=w;
+    height = h;
+  }
+};
+
+typedef  map<string, struct PageSize> PagesizeMap;
+
 class RtfGenerator : public highlight::CodeGenerator
   {
   public:
@@ -47,10 +61,16 @@ class RtfGenerator : public highlight::CodeGenerator
 
     ~RtfGenerator();
 
+   /** Override base class function to initialize tags immediately
+      * after the style definition is loaded
+
+     \param  stylePath Path of style definition
+   */
+   bool initTheme(const string& themePath);
+
    /** prints document header
-       \param  title Title of the document
     */
-    string getHeader(const string & title);
+    string getHeader();
 
     /** Prints document footer*/
     string getFooter();
@@ -58,8 +78,14 @@ class RtfGenerator : public highlight::CodeGenerator
     /** Prints document body*/
     void printBody();
 
+   /** \param page size*/
+   void setPageSize(const string & ps);
+
   private:
 
+    PagesizeMap psMap;
+    string pageSize;
+
     /** \return escaped character*/
     virtual string maskCharacter(unsigned char );
 
