@@ -20,6 +20,7 @@
 
 #include <string>
 #include <vector>
+#include <sstream>
 
 using namespace std;
 
@@ -34,11 +35,6 @@ namespace StringTools
       \returns lowercase string  */
   string lowerCase(const string &s);
 
-  /** \param s String
-      \param assureGreaterZero set true if return value should be > 0
-      \returns Integer value */
-  int str2int(string s, bool assureGreaterZero=false);
-
   /** \return true if c is alpa or underscore */
   bool isAlpha(unsigned char c);
 
@@ -54,8 +50,22 @@ namespace StringTools
        \return value between "(", ")" */
   string getParantheseVal(const string &s);
 
+  /** \param s string containing tokens
+      \param delim Token delimiter
+      \return vector containing found tokens */
   vector <string> splitString(const string& s, unsigned char delim);
 
+  /** \param val variable of specified type which will contain the numeric value
+      \param s string containing a number
+      \param f format specifier function (IO manipulator)
+      \return true if successfull */
+  template <class T>
+  bool str2num(T &val, const std::string& s, std::ios_base& (*f)(std::ios_base&))
+  {
+    std::istringstream iss(s);
+    return !(iss >> f >> val).fail();
+  }
+
 }
 
 #endif
