@@ -18,11 +18,10 @@
 #ifndef STYLECOLOUR_H
 #define STYLECOLOUR_H
 
+#include "enums.h"
+
 #include <string>
-#include <sstream>
-#include <fstream>
-#include <cmath>
-#include <sstream>
+
 
 using namespace std;
 
@@ -32,15 +31,20 @@ namespace highlight {
 * @author Andre Simon
  */
 
+struct RGBVal {
+  string red, green, blue;
+  int iRed, iGreen, iBlue;
+};
+
 class StyleColour
   {
   public:
     /** Constructor
-        \param r_hex Red value in hex notation
-        \param g_hex Blue value in hex notation
-        \param b_hex Green value in hex notation
+        \param red Red value in hex notation
+        \param green Blue value in hex notation
+        \param blue Green value in hex notation
     */
-    StyleColour(const string & r_hex, const string & g_hex, const string & b_hex);
+    StyleColour(const string & red, const string & green, const string & blue);
 
     /** Constructor
         \param styleColourString String with rgb values
@@ -53,53 +57,29 @@ class StyleColour
    /** Sets red, green and blue values
      \param styleColourString String containing colour attributes
    */
-   void setRGBValues(const string & styleColourString);
+   void setRGB(const string & styleColourString);
 
     /** Sets red value
-        \param r_hex New red value */
-    void setRedValue(const string & r_hex);
+        \param red New red value */
+    void setRed(const string & red);
 
     /** Sets green value
-        \param g_hex New green value */
-    void setGreenValue(const string & g_hex);
+        \param green New green value */
+    void setGreen(const string & green);
 
     /** Sets blue value
-        \param b_hex New blue value */
-    void setBlueValue(const string & b_hex);
+        \param blue New blue value */
+    void setBlue(const string & blue);
 
-    /** \return Red value in hex format */
-    string& getHexRedValue();
-    /** \return Green value in hex format */
-    string& getHexGreenValue();
-    /** \return Blue value in hex format */
-    string& getHexBlueValue();
-
-    /** \return Red value in latex format */
-    string getLatexRedValue();
-    /** \return Green value in latex format */
-    string getLatexGreenValue();
-    /** \return Blue value in latex format */
-    string getLatexBlueValue();
-
-    /** \return Red value in tex format */
-    string getTexRedValue();
-    /** \return Green value in tex format */
-    string getTexGreenValue();
-    /** \return Blue value in tex format */
-    string getTexBlueValue();
-
-    /** \return Red value in RTF format */
-    string getRTFRedValue();
-    /** \return Green value in RTF format */
-    string getRTFGreenValue();
-    /** \return Blue value in RTF format */
-    string getRTFBlueValue();
+    /** return RGB calues in specified format */
+    string getRed(OutputType type);
+    string getGreen(OutputType type);
+    string getBlue(OutputType type);
 
   private:
-    string r, g, b;
+    RGBVal rgb;
     string int2str(int);
     string float2str(double);
-    int hex2dec(const string &hexVal);
   };
 
 }
