@@ -48,9 +48,8 @@ class TexGenerator : public highlight::CodeGenerator
     ~TexGenerator();
 
    /** prints document header
-       \param  title Title of the document
     */
-    string getHeader(const string & title);
+    string getHeader();
 
     /** Prints document footer*/
     string getFooter();
