@@ -46,9 +46,8 @@ class XmlGenerator : public highlight::CodeGenerator
     ~XmlGenerator();
 
    /** prints document header
-       \param  title Title of the document
     */
-    string getHeader(const string & title);
+    string getHeader();
 
     /** Prints document footer*/
     string getFooter();
@@ -67,9 +66,6 @@ class XmlGenerator : public highlight::CodeGenerator
     /** \return escaped character*/
     virtual string maskCharacter(unsigned char );
 
-
-//    string getNewLine();
-
     string getOpenTag(const string& );
     string getCloseTag(const string& );
 
